@@ -3,7 +3,6 @@ package internal
 import (
 	"fmt"
 	"math"
-	"regexp"
 	"runtime/debug"
 	"sync"
 	"time"
@@ -12,6 +11,7 @@ import (
 	log "github.com/sirupsen/logrus"
 	"github.com/walles/moor/v2/internal/linemetadata"
 	"github.com/walles/moor/v2/internal/reader"
+	"github.com/walles/moor/v2/internal/search"
 	"github.com/walles/moor/v2/internal/textstyles"
 	"github.com/walles/moor/v2/twin"
 )
@@ -19,7 +19,7 @@ import (
 type PagerMode interface {
 	onKey(key twin.KeyCode)
 	onRune(char rune)
-	drawFooter(statusText string, spinner string)
+	drawFooter(filenameText string, statusText string, spinner string)
 }
 
 type StatusBarOption int
@@ -64,16 +64,15 @@ type Pager struct {
 	// mode is better?
 	mode PagerMode
 
-	searchString  string
-	searchPattern *regexp.Regexp
+	search search.Search
 
 	// This should never be null while paging. Configured in NewPager().
 	searchHistory *SearchHistory
 
-	filterPattern *regexp.Regexp
+	filter search.Search
 
 	// We used to have a "Following" field here. If you want to follow, set
-	// TargetLineNumber to LineNumberMax() instead, see below.
+	// TargetLineNumber to linemetadata.IndexMax() instead, see below.
 
 	isShowingHelp bool
 	preHelpState  *_PreHelpState
@@ -242,7 +241,7 @@ func NewPager(readers ...*reader.ReaderImpl) *Pager {
 	pager.mode = PagerModeViewing{pager: &pager}
 	pager.filteringReader = FilteringReader{
 		BackingReader: readers[0], // Always start with the first reader
-		FilterPattern: &pager.filterPattern,
+		Filter:        &pager.filter,
 	}
 
 	searchHistory := BootSearchHistory("")
@@ -321,15 +320,27 @@ func renderHelpText(help string) []twin.StyledRune {
 //
 // Single quoted parts of the help text will be bolded.
 //
-// footer example value: "file.txt: 123 lines  0%"
+// prefix example value: "[1/3] "
+// filename example value: "file.txt"
+// status example value: ": 123 lines  0%"
 // help example value: "Press 'h' for help, 'q' to quit"
-func (p *Pager) setFooter(footer string, help string) {
+func (p *Pager) setFooter(prefix string, filename string, status string, help string) {
 	width, height := p.screen.Size()
 
 	pos := 0
 
-	// File name and percentage, no keyboard shortcut highlighting
-	for _, token := range footer + "  " {
+	// Prefix (multiple open files)
+	for _, token := range prefix {
+		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, statusbarStyle))
+	}
+
+	// File name
+	for _, token := range filename {
+		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, statusbarFileStyle))
+	}
+
+	// percentage,
+	for _, token := range status + "  " {
 		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, statusbarStyle))
 	}
 
@@ -420,9 +431,8 @@ func (p *Pager) setTargetLine(targetLine *linemetadata.Index) {
 		return
 	}
 
-	// The value 1000 here is supposed to be larger than any possible screen
-	// height, to give us some lookahead and to avoid fetching too few lines.
-	targetValue := targetLine.Index() + 1000
+	// Set the target with some lookahead to avoid fetching too few lines.
+	targetValue := targetLine.Index() + reader.DEFAULT_PAUSE_AFTER_LINES/2
 	if targetValue < targetLine.Index() {
 		// Overflow detected, clip to max int
 		targetValue = math.MaxInt
@@ -490,7 +500,7 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			select {
 			case <-p.readerSwitched:
 				// A different reader is now active
-				p.filterPattern = nil
+				p.filter = search.Search{}
 
 				p.readerLock.Lock()
 				r = p.readers[p.currentReader]
@@ -621,7 +631,10 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 			return
 
 		case eventMoreLinesAvailable:
-			if p.TargetLine != nil {
+			// Without the isViewing() check, following will continue while
+			// searching, and I prefer it to stop so people can see what they
+			// are searching in.
+			if p.isViewing() && p.TargetLine != nil {
 				// The user wants to scroll down to a specific line number
 				if linemetadata.IndexFromLength(p.Reader().GetLineCount()).IsBefore(*p.TargetLine) {
 					// Not there yet, keep scrolling
@@ -724,7 +737,7 @@ func (p *Pager) fitsOnOneScreen() bool {
 
 	lines := reader.GetLines(linemetadata.Index{}, reader.GetLineCount())
 	for _, line := range lines.Lines {
-		rendered := line.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, nil).StyledRunes
+		rendered := line.HighlightedTokens(twin.StyleDefault, twin.StyleDefault, search.Search{}, width+1).StyledRunes
 		if len(rendered) > width {
 			// This line is too long to fit on one screen line, no fit
 			return false
