@@ -11,7 +11,6 @@ import (
 	"sync/atomic"
 	"syscall"
 
-	log "github.com/sirupsen/logrus"
 	"golang.org/x/sys/unix"
 	"golang.org/x/term"
 )
@@ -69,7 +68,7 @@ func (r *interruptableReaderImpl) read(p []byte) (n int, err error) {
 		closeErr := r.shutdownPipeReader.Close()
 		if closeErr != nil {
 			// This should never happen, but if it does we should log it
-			log.Info("Failed to close shutdown pipe reader: ", closeErr)
+			log.Info(fmt.Sprint("Failed to close shutdown pipe reader: ", closeErr))
 		}
 
 		err = io.EOF
@@ -92,7 +91,7 @@ func (r *interruptableReaderImpl) Interrupt() {
 	err := r.shutdownPipeWriter.Close()
 	if err != nil {
 		// This should never happen, but if it does we should log it
-		log.Warn("Failed to close shutdown pipe writer: ", err)
+		log.Info(fmt.Sprint("Failed to close shutdown pipe writer: ", err))
 	}
 }
 
@@ -166,13 +165,13 @@ func (screen *UnixScreen) setupTtyInTtyOut() error {
 	if err != nil {
 		return err
 	}
-	log.Info("ttyin terminal state: ", fmt.Sprintf("%+v", ttyInTerminalState))
+	log.Info(fmt.Sprintf("ttyin terminal state: %+v", ttyInTerminalState))
 
 	ttyOutTerminalState, err := term.GetState(int(screen.ttyOut.Fd()))
 	if err != nil {
 		return err
 	}
-	log.Info("ttyout terminal state: ", fmt.Sprintf("%+v", ttyOutTerminalState))
+	log.Info(fmt.Sprintf("ttyout terminal state: %+v", ttyOutTerminalState))
 
 	return nil
 }
